@@ -1,14 +1,15 @@
 package Dist::Zilla::Plugin::PodCoverageTests;
-BEGIN {
-  $Dist::Zilla::Plugin::PodCoverageTests::VERSION = '4.200000';
+{
+  $Dist::Zilla::Plugin::PodCoverageTests::VERSION = '4.300010';
 }
 # ABSTRACT: a release test for Pod coverage
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
 
+use namespace::autoclean;
+
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 
@@ -21,7 +22,7 @@ Dist::Zilla::Plugin::PodCoverageTests - a release test for Pod coverage
 
 =head1 VERSION
 
-version 4.200000
+version 4.300010
 
 =head1 DESCRIPTION
 
@@ -42,7 +43,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
