@@ -1,10 +1,12 @@
 package Dist::Zilla::Stash::User;
-BEGIN {
-  $Dist::Zilla::Stash::User::VERSION = '4.200009';
+{
+  $Dist::Zilla::Stash::User::VERSION = '4.300010';
 }
 use Moose;
 # ABSTRACT: a stash of user name and email
 
+use namespace::autoclean;
+
 has name => (
   is  => 'ro',
   isa => 'Str',
@@ -23,6 +25,7 @@ sub authors {
 }
 
 with 'Dist::Zilla::Role::Stash::Authors';
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -34,7 +37,7 @@ Dist::Zilla::Stash::User - a stash of user name and email
 
 =head1 VERSION
 
-version 4.200009
+version 4.300010
 
 =head1 AUTHOR
 
@@ -42,7 +45,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
